@@ -1,11 +1,8 @@
 from datetime import datetime
 from typing import Optional, Any
-
-from .entity import Entity
 from .metadata import Metadata
 from .named_entity import NamedEntity
 from .time import Time
-from tracardi.service.storage.crud import StorageCrud
 from .type import Type
 from .value_object.storage_info import StorageInfo
 
@@ -27,9 +24,6 @@ class Rule(NamedEntity):
             ))
         super().__init__(**data)
 
-    def storage(self) -> StorageCrud:
-        return StorageCrud("rule", Rule, entity=self)
-
     @staticmethod
     def storage_info() -> StorageInfo:
         return StorageInfo(
