@@ -37,4 +37,12 @@ async def save_profile(profile: Profile):
     result = await StorageFor(profile).index().save()
     if elastic.refresh_profiles_after_save:
         await storage_manager('profile').flush()
-    return result
\ No newline at end of file
+    return result
+
+
+async def refresh():
+    return await storage_manager('profile').refresh()
+
+
+async def flush():
+    return await storage_manager('profile').flush()
