@@ -2,7 +2,7 @@ from tracardi.domain.profile import Profile
 from tracardi.domain.session import Session
 from tracardi.domain.value_object.bulk_insert_result import BulkInsertResult
 from tracardi.domain.entity import Entity
-from tracardi.service.storage.factory import StorageFor
+from tracardi.service.storage.factory import StorageFor, storage_manager
 
 
 async def save_session(session: Session, profile: Profile, persist_session: bool = True):
@@ -12,3 +12,11 @@ async def save_session(session: Session, profile: Profile, persist_session: bool
         return await StorageFor(session).index().save()
     else:
         return BulkInsertResult()
+
+
+async def refresh():
+    return await storage_manager('session').refresh()
+
+
+async def flush():
+    return await storage_manager('session').flush()
