@@ -3,10 +3,10 @@ import time
 from tracardi.service.storage.factory import storage_manager, StorageForBulk
 
 
-async def load_tasks():
+async def load_pending_tasks(limit: int = 100):
     now = time.time()
     query = {
-        "size": 100,
+        "size": limit,
         "query": {
             "bool": {
                 "must": [
@@ -33,3 +33,7 @@ async def load_tasks():
 
 async def save_tasks(tasks):
     return await StorageForBulk(tasks).index('task').save()
+
+
+async def load_all(limit: int = 100):
+    return await storage_manager('task').load_all(limit)
