@@ -1,20 +1,16 @@
 import tracardi.service.storage.drivers.elastic.profile
 import tracardi.service.storage.drivers.elastic.session
 import tracardi.service.storage.drivers.elastic.event
-import tracardi.service.storage.drivers.elastic.events
 import tracardi.service.storage.drivers.elastic.flow
-import tracardi.service.storage.drivers.elastic.rules
+import tracardi.service.storage.drivers.elastic.rule
 import tracardi.service.storage.drivers.elastic.segment
 import tracardi.service.storage.drivers.elastic.plugin
 import tracardi.service.storage.drivers.elastic.debug_info
 import tracardi.service.storage.drivers.elastic.resource
-import tracardi.service.storage.drivers.elastic.flows
-import tracardi.service.storage.drivers.elastic.actions
-import tracardi.service.storage.drivers.elastic.resources
-import tracardi.service.storage.drivers.elastic.profiles
+import tracardi.service.storage.drivers.elastic.action
 import tracardi.service.storage.drivers.elastic.console_log
-import tracardi.service.storage.drivers.elastic.segments
 import tracardi.service.storage.drivers.elastic.task
+import tracardi.service.storage.drivers.elastic.api_instance
 
 
 class ElasticDriver:
@@ -31,21 +27,13 @@ class ElasticDriver:
     def event(self):
         return tracardi.service.storage.drivers.elastic.event
 
-    @property
-    def events(self):
-        return tracardi.service.storage.drivers.elastic.events
-
     @property
     def flow(self):
         return tracardi.service.storage.drivers.elastic.flow
 
     @property
-    def flows(self):
-        return tracardi.service.storage.drivers.elastic.flows
-
-    @property
-    def rules(self):
-        return tracardi.service.storage.drivers.elastic.rules
+    def rule(self):
+        return tracardi.service.storage.drivers.elastic.rule
 
     @property
     def segment(self):
@@ -64,20 +52,8 @@ class ElasticDriver:
         return tracardi.service.storage.drivers.elastic.resource
 
     @property
-    def actions(self):
-        return tracardi.service.storage.drivers.elastic.actions
-
-    @property
-    def resources(self):
-        return tracardi.service.storage.drivers.elastic.resources
-
-    @property
-    def segments(self):
-        return tracardi.service.storage.drivers.elastic.segments
-
-    @property
-    def profiles(self):
-        return tracardi.service.storage.drivers.elastic.profiles
+    def action(self):
+        return tracardi.service.storage.drivers.elastic.action
 
     @property
     def console_log(self):
@@ -86,3 +62,7 @@ class ElasticDriver:
     @property
     def task(self):
         return tracardi.service.storage.drivers.elastic.task
+
+    @property
+    def api_instance(self):
+        return tracardi.service.storage.drivers.elastic.api_instance
